@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.25.4.2 2004/09/21 11:13:21 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.25.4.7 2004/11/18 13:22:36 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -25,8 +25,8 @@
 #include "config.h"
 #endif
 
-#include "ephy-encodings.h"
 #include "ephy-embed.h"
+#include <gtk/gtkwidget.h>
 
 #include <gtkmozembed.h>
 #include <nsCOMPtr.h>
@@ -41,16 +41,22 @@
 #include <nsIRequest.h>
 
 #ifdef ALLOW_PRIVATE_API
-#include "nsIContentViewer.h"
+#include <nsIContentViewer.h>
 #endif
 
+#ifdef HAVE_MOZILLA_PSM
+#include <nsISecureBrowserUI.h>
+#endif
+
+class EphyBrowser;
+
 class EphyEventListener : public nsIDOMEventListener
 {
 public:
 	EphyEventListener();
 	virtual ~EphyEventListener();
 
-	nsresult Init(EphyEmbed *aOwner);
+	nsresult Init (EphyBrowser *aOwner);
 
 	NS_DECL_ISUPPORTS
 
@@ -59,16 +65,13 @@ public:
 	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent) = 0;
 
 protected:
-	EphyEmbed *mOwner;
+	EphyBrowser *mOwner;
 };
 
 class EphyFaviconEventListener : public EphyEventListener
 {
 public:
 	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
-
-private:
-	nsresult HandleFaviconLink (nsIDOMNode *node);
 };
 
 class EphyPopupBlockEventListener : public EphyEventListener
@@ -77,8 +80,18 @@ public:
 	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
 };
 
+class EphyModalAlertEventListener : public EphyEventListener
+{
+public:
+	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
+};
+
 class EphyBrowser
 {
+friend class EphyEventListener;
+friend class EphyFaviconEventListener;
+friend class EphyPopupBlockEventListener;
+friend class EphyModalAlertEventListener;
 public:
 	EphyBrowser();
 	~EphyBrowser();
@@ -133,18 +146,20 @@ public:
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
-	nsresult SetSecurityInfo (nsIRequest *aRequest);
-	nsresult GetSecurityDescription (nsACString &aDescription);
+	nsresult GetSecurityInfo (PRUint32 *aState, nsACString &aDescription);
+	nsresult ShowCertificate ();
 
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
-
 private:
+	GtkWidget *mEmbed;
+
 	nsCOMPtr<nsIDOMDocument> mTargetDocument;
 	nsCOMPtr<nsIDOMEventTarget> mEventTarget;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
-	nsCOMPtr<nsISupports> mSecurityInfo;
+	nsCOMPtr<nsISecureBrowserUI> mSecurityInfo;
 	EphyFaviconEventListener *mFaviconEventListener;
 	EphyPopupBlockEventListener *mPopupBlockEventListener;
+	EphyModalAlertEventListener *mModalAlertListener;
 	PRBool mInitialized;
 
 	nsresult GetListener (void);
