@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.17.4.2 2004/10/10 16:18:26 marco Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.17.4.4 2004/11/13 21:27:25 chpe Exp $
  */
 
 /*
@@ -49,7 +49,9 @@
 #include <nsICRLInfo.h>
 #include <nsISimpleEnumerator.h>
 #include <nsIArray.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtkdialog.h>
@@ -73,7 +75,7 @@
 #include <gtk/gtktextbuffer.h>
 #include <gtk/gtktextview.h>
 #include <gtk/gtkprogressbar.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <time.h>
 
 #include "GtkNSSDialogs.h"
