@@ -34,29 +34,33 @@
  * the provisions above, a recipient may use your version of this file under
  * the terms of any one of the MPL, the GPL or the LGPL.
  *
- * ***** END LICENSE BLOCK ***** */
+ * ***** END LICENSE BLOCK *****
+ *
+ * $Id: MozDownload.h,v 1.18 2004/06/03 18:51:32 marco Exp $
+ */
 
 #ifndef MozDownload_h__
 #define MozDownload_h__
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "mozilla-embed-persist.h"
-#include "nsIDownload.h"
-#include "nsIWebProgressListener.h"
-#include "nsIHelperAppLauncherDialog.h"
-#include "nsIExternalHelperAppService.h"
-#include "nsIDOMDocument.h"
-
-#include "nsString.h"
-#include "nsIURI.h"
-#include "nsILocalFile.h"
-#include "nsIWebBrowserPersist.h"
-#include "nsIObserver.h"
-#include "nsIRequest.h"
-#include "nsIMIMEInfo.h"
-
 #include "downloader-view.h"
 #include "ephy-download.h"
 #include "ephy-embed-shell.h"
+
+#include <nsIDownload.h>
+#include <nsIWebProgressListener.h>
+#include <nsIDOMDocument.h>
+#include <nsIURI.h>
+#include <nsILocalFile.h>
+#include <nsIWebBrowserPersist.h>
+#include <nsIObserver.h>
+#include <nsIRequest.h>
+#include <nsIMIMEInfo.h>
+
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 /* MozDownload
@@ -95,6 +99,7 @@ public:
 	virtual ~MozDownload();
     
 	NS_DECL_ISUPPORTS
+	NS_DECL_NSITRANSFER
 	NS_DECL_NSIDOWNLOAD
 	NS_DECL_NSIWEBPROGRESSLISTENER
 
@@ -106,14 +111,15 @@ public:
 	nsresult GetCurrentProgress (PRInt32 *aCurrentProgress);
 	nsresult GetTotalProgress   (PRInt32 *aTProgress);
  	nsresult GetElapsedTime     (PRInt64 *aTProgress);
-	nsresult InitForEmbed       (nsIURI *aSource, nsILocalFile *aTarget,
+	nsresult InitForEmbed       (nsIURI *aSource, nsIURI *aTarget,
 				     const PRUnichar *aDisplayName, nsIMIMEInfo *aMIMEInfo,
 				     PRInt64 startTime, nsIWebBrowserPersist *aPersist,
 				     MozillaEmbedPersist *aEmbedPersist, PRInt32 aMaxSize);
 
 protected:
 	nsCOMPtr<nsIURI>        mSource;
-	nsCOMPtr<nsILocalFile>  mDestination;
+	nsCOMPtr<nsIURI>        mDestination;
+
 	nsCOMPtr<nsIMIMEInfo>   mMIMEInfo;
 	PRInt64		    	mLastUpdate;
 	PRInt64                 mStartTime;
