@@ -14,8 +14,14 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-dnd.c,v 1.15 2004/03/17 09:02:35 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-dnd.h"
 #include "ephy-string.h"
 #include "ephy-node.h"
@@ -31,18 +37,24 @@
  * GMC also fails to do this as well.
  */
 static void
-add_one_netscape_url (const char *url, int x, int y, int w, int h, gpointer data)
+add_one_netscape_url (const char *url, const char *title, gpointer data)
 {
         GString *result;
 
         result = (GString *) data;
-        if (result->len == 0) {
+        if (result->len == 0)
+	{
                 g_string_append (result, url);
+		if (title)
+		{
+			g_string_append (result, "\n");
+	                g_string_append (result, title);
+		}
         }
 }
 
 static void
-add_one_uri (const char *uri, int x, int y, int w, int h, gpointer data)
+add_one_uri (const char *uri, const char *title, gpointer data)
 {
         GString *result;
 
@@ -53,7 +65,7 @@ add_one_uri (const char *uri, int x, int y, int w, int h, gpointer data)
 }
 
 static void
-add_one_topic (const char *uri, int x, int y, int w, int h, gpointer data)
+add_one_topic (const char *uri, const char *title, gpointer data)
 {
         GString *result;
 
