@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.41 2004/07/05 00:02:09 marco Exp $
+ *  $Id: ephy-notebook.c,v 1.46.4.5 2004/11/27 23:41:52 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,6 +25,7 @@
 #endif
 
 #include "ephy-notebook.h"
+#include "ephy-stock-icons.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
 #include "ephy-marshal.h"
@@ -35,8 +36,10 @@
 #include "ephy-shell.h"
 #include "ephy-debug.h"
 #include "ephy-favicon-cache.h"
-#include "ephy-ellipsizing-label.h"
+#include "ephy-label.h"
 #include "ephy-spinner.h"
+#include "ephy-string.h"
+#include "ephy-stock-icons.h"
 
 #include <glib-object.h>
 #include <gtk/gtkeventbox.h>
@@ -593,7 +596,6 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 				guint info, guint time, EphyTab *tab)
 {
 	GList *uri_list = NULL;
-	GnomeVFSURI *uri;
 	gchar **tmp;
 
 	g_signal_stop_emission_by_name (widget, "drag_data_received");
@@ -606,33 +608,32 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	{
 		/* URL_TYPE has format: url \n title */
 		tmp = g_strsplit (selection_data->data, "\n", 2);
-		if (tmp)
+		if (tmp != NULL && tmp[0] != NULL)
 		{
-			uri = gnome_vfs_uri_new (tmp[0]);
-			if (uri)
-			{
-				uri_list = g_list_append (uri_list, uri);
-			}
-			g_strfreev (tmp);
+			uri_list = g_list_prepend (uri_list, g_strdup (tmp[0]));
 		}
+
+		g_strfreev (tmp);
 	}
 	else if (selection_data->target == gdk_atom_intern (EPHY_DND_URI_LIST_TYPE, FALSE))
 	{
-		uri_list = gnome_vfs_uri_list_parse (selection_data->data);
+		uri_list = ephy_string_parse_uri_list (selection_data->data);
 	}
 	else
 	{
-		g_assert_not_reached ();
+		g_return_if_reached ();
 	}
 
-	if (uri_list)
+	if (uri_list != NULL)
 	{
 		EphyWindow *window;
 
 		window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (widget)));
 
 		ephy_window_load_in_tabs (window, tab, uri_list);
-		gnome_vfs_uri_list_free (uri_list);
+
+		g_list_foreach (uri_list, (GFunc) g_free, NULL);
+		g_list_free (uri_list);
 	}
 }
 
@@ -794,7 +795,7 @@ sync_label (EphyTab *tab, GParamSpec *pspec, GtkWidget *proxy)
 
 	if (title)
 	{
-		ephy_ellipsizing_label_set_text (EPHY_ELLIPSIZING_LABEL (label), title);
+		ephy_label_set_text (EPHY_LABEL (label), title);
 		gtk_tooltips_set_tip (tips, ebox, title, NULL);
 	}
 }
@@ -845,12 +846,10 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 {
 	GtkWidget *window, *hbox, *label_hbox, *label_ebox;
 	GtkWidget *label, *close_button, *image, *spinner, *icon;
-	int h = -1, w = -1;
+	GtkIconSize close_icon_size;
 
 	window = gtk_widget_get_toplevel (GTK_WIDGET (nb));
 
-	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
-
 	/* set hbox spacing and label padding (see below) so that there's an
 	 * equal amount of space around the label */
 	hbox = gtk_hbox_new (FALSE, 4);
@@ -866,9 +865,8 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	close_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (close_button),
 			       GTK_RELIEF_NONE);
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-					  GTK_ICON_SIZE_MENU);
-	gtk_widget_set_size_request (close_button, w, h);
+	close_icon_size = gtk_icon_size_from_name (EPHY_ICON_SIZE_TAB_BUTTON);
+	image = gtk_image_new_from_stock (EPHY_STOCK_CLOSE_TAB, close_icon_size);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
 	gtk_box_pack_start (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 
@@ -886,9 +884,8 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
 
 	/* setup label */
-        label = ephy_ellipsizing_label_new ("");
-	ephy_ellipsizing_label_set_mode (EPHY_ELLIPSIZING_LABEL (label),
-					 EPHY_ELLIPSIZE_START);
+        label = ephy_label_new ("");
+	ephy_label_set_ellipsize (EPHY_LABEL (label), PANGO_ELLIPSIZE_END);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_misc_set_padding (GTK_MISC (label), 0, 0);
 	gtk_box_pack_start (GTK_BOX (label_hbox), label, TRUE, TRUE, 0);
@@ -959,12 +956,15 @@ ephy_notebook_add_tab (EphyNotebook *nb,
 
 	g_signal_emit (G_OBJECT (nb), signals[TAB_ADDED], 0, tab);
 
+	/* The signal handler may have reordered the tabs */
+	position = gtk_notebook_page_num (GTK_NOTEBOOK (nb), GTK_WIDGET (tab));
+
 	if (jump_to)
 	{
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (nb),
-					       position);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (nb), position);
 		g_object_set_data (G_OBJECT (tab), "jump_to",
 				   GINT_TO_POINTER (jump_to));
+
 	}
 }
 
@@ -1001,23 +1001,12 @@ void
 ephy_notebook_remove_tab (EphyNotebook *nb,
 			  EphyTab *tab)
 {
-	int num, position, curr;
+	int position, curr;
 	GtkWidget *label, *ebox;
 
 	g_return_if_fail (EPHY_IS_NOTEBOOK (nb));
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
-	num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
-	if (num <= 1)
-	{
-		GtkWidget *window;
-		window = gtk_widget_get_toplevel (GTK_WIDGET (nb));
-
-		g_signal_emit (G_OBJECT (nb), signals[TAB_REMOVED], 0, tab);
-		gtk_widget_destroy (window);
-		return;
-	}
-
 	/* Remove the page from the focused pages list */
 	nb->priv->focused_pages =  g_list_remove (nb->priv->focused_pages,
 						  tab);
@@ -1054,4 +1043,10 @@ ephy_notebook_remove_tab (EphyNotebook *nb,
 	g_signal_emit (G_OBJECT (nb), signals[TAB_REMOVED], 0, tab);
 
 	g_object_unref (tab);
+
+	/* if that was the last tab, destroy the window */
+	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) == 0)
+	{
+		gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (nb)));
+	}
 }
