@@ -15,12 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.h,v 1.26 2004/03/23 21:17:12 chpe Exp $
+ *  $Id: ephy-window.h,v 1.28.4.1 2004/10/08 21:12:09 chpe Exp $
  */
 
 #ifndef EPHY_WINDOW_H
 #define EPHY_WINDOW_H
 
+#include "ephy-notebook.h"
 #include "ephy-embed.h"
 #include "ephy-tab.h"
 #include "ephy-dialog.h"
@@ -38,9 +39,9 @@ G_BEGIN_DECLS
 #define EPHY_IS_WINDOW_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_WINDOW))
 #define EPHY_WINDOW_GET_CLASS(o)(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_WINDOW, EphyWindowClass))
 
-typedef struct EphyWindowClass EphyWindowClass;
-typedef struct _EphyWindow EphyWindow;
-typedef struct EphyWindowPrivate EphyWindowPrivate;
+typedef struct _EphyWindowClass		EphyWindowClass;
+typedef struct _EphyWindow		EphyWindow;
+typedef struct _EphyWindowPrivate	EphyWindowPrivate;
 
 struct _EphyWindow
 {
@@ -52,14 +53,11 @@ struct _EphyWindow
 	GObject *ui_merge;
 };
 
-struct EphyWindowClass
+struct _EphyWindowClass
 {
         GtkWindowClass parent_class;
 };
 
-/* Include the header down here to resolve circular dependency */
-#include "ephy-notebook.h"
-
 GType		  ephy_window_get_type		  (void);
 
 EphyWindow	 *ephy_window_new		  (void);
@@ -71,6 +69,8 @@ void		  ephy_window_set_print_preview	  (EphyWindow *window,
 
 GtkWidget	 *ephy_window_get_toolbar	  (EphyWindow *window);
 
+GtkWidget	 *ephy_window_get_bookmarksbar	  (EphyWindow *window);
+
 GtkWidget	 *ephy_window_get_notebook	  (EphyWindow *window);
 
 GtkWidget	 *ephy_window_get_statusbar	  (EphyWindow *window);
@@ -89,6 +89,10 @@ void		  ephy_window_jump_to_tab	  (EphyWindow *window,
 void		  ephy_window_load_url		  (EphyWindow *window,
 						   const char *url);
 
+void		  ephy_window_load_in_tabs	  (EphyWindow *window,
+						   EphyTab *first_tab,
+						   GList *uri_list);
+
 void		  ephy_window_set_zoom		  (EphyWindow *window,
 						   float zoom);
 
